#!/usr/bin/env python
#! -*- coding: utf-8 -*-

from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

__author__ = 'QU Xiaofeng'

from .imread import imread, imread_eval, import_imread_from

__all__ = [
	'imread',
	'imread_eval',
	'import_imread_from'
	]
